@@ -25,5 +25,11 @@
  *
  */
 
-int intel_decode(uint32_t *data, int count, uint32_t hw_offset, uint32_t devid);
+#include <stdint.h>
+
+int intel_decode(uint32_t *data, int count,
+		 uint32_t hw_offset,
+		 uint32_t devid,
+		 uint32_t ignore_end_of_batchbuffer);
+void intel_decode_context_set_head_tail(uint32_t head, uint32_t tail);
 void intel_decode_context_reset(void);
